/**
 * @file   example4.cc
 * @author Sebastien Fourey <http://www.greyc.ensicaen.fr/~seb>
 * @date   Tue Aug 21
 * 
 * @brief  Sample drawing using the board library.
 * 
 */
/*
 * @file   example4.cc
 * @author Sebastien Fourey <http://www.greyc.ensicaen.fr/~seb>
 * @date   Tue Aug 21
 * 
 * @brief  Illustration of the use of Board, ShapeList and Group.
 * 
 * @copyright 
 */
#include <cstdlib>
#include <iostream>
#include <fstream>
#include <cmath>
#include "Board.h"

using namespace BoardLib;

int main( int , char *[] )
{
  Board board;

  board.clear( Color(200,255,200) );
  
  board << Rectangle( -15, 10, 30, 20, Color::Red, Color::none, 0.1 );
  board << Rectangle( -15, 10, 30, 20, Color::Red, Color::none, 0.1 ).rotateDeg( 45.0 );

  Group g;
  
  g << Line( -5, 2, 5, 2, Color::Red, 1 )
    << Rectangle( -5, 2, 1, 4, Color::none, Color::Blue, 1 )
    << Rectangle( 4, 2, 1, 4, Color::none, Color::Blue, 1 )
    << Ellipse( 0, 0, 5, 2, Color::Red, Color::none, 1 );

  Group g2(g);
  Group g3(g);
  
  g2.translate( 0, 6 );
  g3.translate( 0, -6 );

  Group f;
  f << g << g2 << g3;

  board << f.rotateDeg( 45.0 );

  ShapeList l;
  Circle c( 0, 5, 6, Color::Red, Color::Green, 0.2 );
  for ( int i = 0; i < 5; ++i ) 
    l << c.scale( 1, 0.5 );
  ShapeList l2 = l;
  board << l.rotateDeg( -30 ).scale( 3, 1.0 );
  board << l2.rotateDeg( -30 );
  
  board.saveEPS( "draw4.eps" );
  board.saveFIG( "draw4.fig" );
  board.saveSVG( "draw4.svg" );

  exit(0);
}
